@@ -14,6 +14,8 @@ import glob
 import datetime
 from scipy.stats import mode
 
+import socket
+
 from .object_storage import ObjectStorage
 ObjStorage = ObjectStorage()
 
@@ -94,10 +96,15 @@ NYQUIST_VEL = [8.3,9.6,8.3,12.4,11,12.4,13.8,12.4,13.8,16.5,16.5,16.5,
 # QPE
 ###############
 
+# Quality checks to avoid the inclusion of erroneous data
+STATUS_QC_FLAG_TH = 0.01 #dBADU
+STATUS_QC_FLAG_SWEEP = 19
+STATUS_QC_REMOVE_TH = 13
+
 VPR_REF_HEIGHTS = {'A':1500,'D':2000,'L':2000,'P':1500,'W':1500}
 VPR_REF_RADAR = {'A':'A','P':'A','L':'L','W':'A','D':'D'}
 
-A_QPE = 250
+A_QPE = 316
 B_QPE = 1.5
 
 MAX_VPR_CORRECTION_DB = 4.77
@@ -246,27 +253,34 @@ BORDER_SHP = shapefile.Reader(str(path_shp))
 ###############
 # Data retrieval
 ###############
-FOLDER_DATABASE = '/store/msrad/radar/radar_database/'
-FOLDER_RADAR = '/store/msrad/radar/swiss/data/'
-FOLDER_RADARH = '/store/msrad/radar/polarHR/data/'
-FOLDER_CPCCV = '/store/msrad/radar/cpc_validation/daily/'
-COSMO1_START = datetime.datetime(2015,10,1)
-COSMO1E_START = datetime.datetime(2019,7,2)
-FOLDER_RADAR = '/store/msrad/radar/swiss/data/'
-FOLDER_COSMO1 = '/store/s83/owm/COSMO-1/'
-FOLDER_COSMO1E = '/store/s83/osm/KENDA-1/'
-FOLDER_COSMO1_T = '/store/s83/owm/COSMO-1/ORDERS/MDR/'
-FOLDER_COSMO1E_T = '/store/s83/osm/COSMO-1E/ORDERS/MDR/'
-FOLDER_COSMO2_T = '/store/msrad/cosmo/cosmo2/data/'
 FILTER_COMMAND = '~owm/bin/fxfilter'
 CONVERT_COMMAND = '~owm/bin/fxconvert'
 OFFSET_CCS4 = [297,-100]
-FILES_COSMO1_T = sorted(glob.glob(FOLDER_COSMO1_T + '*.nc'))
-TIMES_COSMO1_T = np.array([datetime.datetime.strptime(f[-13:-3],'%Y%m%d%H')
-      for f in FILES_COSMO1_T])
-FILES_COSMO1E_T = sorted(glob.glob(FOLDER_COSMO1E_T + '*.nc'))
-TIMES_COSMO1E_T = np.array([datetime.datetime.strptime(f[-13:-3],'%Y%m%d%H')
-      for f in FILES_COSMO1E_T])
+
+# Folder depends on server:
+if ('lom' in socket.gethostname()) or ('meteoswiss' in socket.gethostname()):
+    FOLDER_RADAR = '/srn/data/'
+    FOLDER_ISO0 = '/srn/data/HZT/'
+elif 'tsa' in socket.gethostname():
+    FOLDER_DATABASE = '/store/msrad/radar/radar_database/'
+    FOLDER_RADAR = '/store/msrad/radar/swiss/data/'
+    FOLDER_RADARH = '/store/msrad/radar/polarHR/data/'
+    FOLDER_CPCCV = '/store/msrad/radar/cpc_validation/daily/'
+
+    FOLDER_ISO0 = '/store/msrad/radar/swiss/data/'
+    COSMO1_START = datetime.datetime(2015,10,1)
+    COSMO1E_START = datetime.datetime(2019,7,2)
+    FOLDER_COSMO1 = '/store/s83/owm/COSMO-1/'
+    FOLDER_COSMO1E = '/store/s83/osm/KENDA-1/'
+    FOLDER_COSMO1_T = '/store/s83/owm/COSMO-1/ORDERS/MDR/'
+    FOLDER_COSMO1E_T = '/store/s83/osm/COSMO-1E/ORDERS/MDR/'
+    FOLDER_COSMO2_T = '/store/msrad/cosmo/cosmo2/data/'
+    FILES_COSMO1_T = sorted(glob.glob(FOLDER_COSMO1_T + '*.nc'))
+    TIMES_COSMO1_T = np.array([datetime.datetime.strptime(f[-13:-3],'%Y%m%d%H')
+        for f in FILES_COSMO1_T])
+    FILES_COSMO1E_T = sorted(glob.glob(FOLDER_COSMO1E_T + '*.nc'))
+    TIMES_COSMO1E_T = np.array([datetime.datetime.strptime(f[-13:-3],'%Y%m%d%H')
+        for f in FILES_COSMO1E_T])
 
  ###############
  # Radar processing
@@ -318,13 +332,16 @@ SLURM_HEADER_R = '''#!/bin/sh
 #SBATCH -t 12:0:00  # time requested in hour:minute:second
 #SBATCH --partition=postproc
 #SBATCH --exclude=tsa-pp020,tsa-pp019,tsa-pp018
-#SBATCH --output="db_gauges_%A_%a.out"
-#SBATCH --error="db_gauges_%A_%a.err"
+#SBATCH --output="db_gauges_%A.out"
+#SBATCH --error="db_gauges_%A.err"
 #SBATCH --mail-type=END,FAIL
 #SBATCH --mail-user=rebecca.gugerli@meteoswiss.ch
 
 export MODULEPATH="/store/msclim/share/modulefiles/modules/all:${MODULEPATH}"
 module load /store/msclim/share/modulefiles/modules/all/cat/tsa-R3.5.2
+
+export RAINFOREST_DATAPATH=/store/msrad/radar/rainforest/rainforest_data/
+
 source /scratch/rgugerli/miniconda3/etc/profile.d/conda.sh
 conda activate rainforest_RandPython
 '''
