@@ -14,6 +14,8 @@ first index of COSMO grids, 'idx_1': second, 'idx_3': third,
 mask' is 1 for points that fall outside of COSMO domain. This lookup table
 is valid only for COSMO data stored in /store/s83/owm/COSMO-1/
 
+**cosmo2_to_rad** : same thing but for COSMO 1E data
+
 **cosmo2_to_rad** : same thing but for COSMO 2 data
 
 **cosmo1T_to_rad** : same thing but for netCDF files of COSMO1 temperature
@@ -43,6 +45,10 @@ and last is Swiss Z coordinate (altitude)
 QPE grid. It is simply a 2D array with 5 columns 
 | sweep | azimuth_idx | range_idx | Swiss Y coord | Swiss X coord|
 
+**qpegrid_to_height_rad** : gives for every pixel of the Swiss Cartesian QPE grid
+the average height of radar observations for a given radar, for every sweep. It is a dictionary
+where the key is the sweep number ( 1 - 20) and the value is a 640 x 710 array of heights above ground
+
 **station_to_qpegrid** : maps every station to the corresponding QPE gridpoint
 it is a dict of keys [station][ncode] and gives the index of every 
 neighbour of every station in the QPE 2D grid 640 x 710 pixels
@@ -65,6 +71,7 @@ from pyart.aux_io import read_metranet
 
 # Local imports
 from . import constants
+from .utils import nanadd_at
 from .wgs84_ch1903 import GPSConverter
 from .object_storage import ObjectStorage
 ObjStorage = ObjectStorage()
@@ -77,6 +84,8 @@ from .constants import cosmo_coords_folder
 from .constants import radar_samples_folder
 from .constants import rfmodels_folder
 
+LOOKUP_FOLDER = Path(os.environ['RAINFOREST_DATAPATH'], 'references', 'lookup_data')
+
 def get_lookup(lookup_type, radar = None):
     """Read a lookup table from the /data/lookup_data folder
 
@@ -87,6 +96,7 @@ def get_lookup(lookup_type, radar = None):
         
         -   qpebias_station
         -   cosmo1_to_rad
+        -   cosmo1e_to_rad
         -   cosmo2_to_rad
         -   cosmo1T_to_rad
         -   cosmo2T_to_rad
@@ -139,6 +149,7 @@ def calc_lookup(lookup_type, radar = None):
     
         -   qpebias_station
         -   cosmo1_to_rad
+        -   cosmo1e_to_rad
         -   cosmo2_to_rad
         -   cosmo1T_to_rad
         -   cosmo2T_to_rad
@@ -160,7 +171,7 @@ def calc_lookup(lookup_type, radar = None):
     neighb_y = 5
     
     # List that contains the computed lookup tables
-    lut_objets = []
+    lut_objects = []
     # List that contains the lookup table filenames
     lut_names = []
 
@@ -199,14 +210,15 @@ def calc_lookup(lookup_type, radar = None):
                     # e.g. x = 563, means that radar pixels are between 563 and 564
                     #x_llc_sta = np.int(x_sta/constants.CART_GRID_SIZE)
                     # For y the columns in the Cartesian lookup tables are upper bounds
-                    # e.g. x = 182, means that radar pixels are between 181 and 182            
+                    # e.g. y = 182, means that radar pixels are between 181 and 182            
                     #y_llc_sta = np.int(np.ceil(y_sta/constants.CART_GRID_SIZE))
                     
                     # x and y are reversed (following the Swiss convention),
                     # therefore, the station cell number needs to be 
                     # defined as follows:
-                    x_llc_sta = np.int(np.ceil(x_sta/constants.CART_GRID_SIZE))
-                    y_llc_sta = np.int(y_sta/constants.CART_GRID_SIZE)
+
+                    x_llc_sta = int(np.ceil(x_sta/constants.CART_GRID_SIZE))
+                    y_llc_sta = int(y_sta/constants.CART_GRID_SIZE)
                     
                     # Distance from all gates to gauge
                     idx = lut_cart[np.logical_and(lut_cart[:,0] == sweep_idx,
@@ -246,12 +258,12 @@ def calc_lookup(lookup_type, radar = None):
             lut_objects.append([all_idx_sta, all_distances_sta, all_heights_sta])
 
 
-    elif lookup_type in ['cosmo1_to_rad', 'cosmo2_to_rad']:
+    elif lookup_type in ['cosmo1_to_rad', 'cosmo1e_to_rad', 'cosmo2_to_rad']:
         
         converter = GPSConverter()
         
-        cosmo_version = int(lookup_type[5])
-        fname_cosmo_coords =  Path(cosmo_coords_folder, 'coords_COSMO{:d}.nc'.
+        cosmo_version = lookup_type.split('cosmo')[1].split('_')[0]
+        fname_cosmo_coords =  Path(cosmo_coords_folder, 'coords_COSMO{:s}.nc'.
                                    format(cosmo_version))
         fname_cosmo_coords = ObjStorage.check_file(fname_cosmo_coords)
 
@@ -367,7 +379,7 @@ def calc_lookup(lookup_type, radar = None):
                 lut[sweep]['mask'] = mask.astype(np.bool_)
 
             lut_names.append(str(lut_name))
-            lut_objects.append([all_idx_sta, all_distances_sta, all_heights_sta])
+            lut_objects.append(lut)
 
 
     elif lookup_type == 'qpebias_station':
@@ -378,6 +390,53 @@ def calc_lookup(lookup_type, radar = None):
                          dtype = np.float32).reshape(640,710)
 
         # TODO
+
+    elif lookup_type == 'qpegrid_to_height_rad':
+        for r in radar:
+            lut_name =  Path(LOOKUP_FOLDER, 'lut_' + lookup_type+'{:s}.p'.format(r))
+
+            try:
+                lut_cart = get_lookup('qpegrid_to_rad', r)
+            except:
+                raise IOError('Could not load qpegrid_to_rad lookup for radar {:s}, compute it first!'.format(r))
+            try:
+                lut_coords = get_lookup('cartcoords_rad', r)
+            except:    
+                raise IOError('Could not load cartcoords_rad lookup for radar {:s}, compute it first!'.format(r))
+
+            Y_QPE_CENTERS = constants.Y_QPE_CENTERS
+            X_QPE_CENTERS = constants.X_QPE_CENTERS
+
+            all_heights_qpe = {}
+
+            for sweep in sweeps:        
+                sweep_idx = sweep - 1
+                heights_qpe =  np.zeros((len(X_QPE_CENTERS), len(Y_QPE_CENTERS)))
+                weights = np.zeros((len(X_QPE_CENTERS), len(Y_QPE_CENTERS)))
+
+                lut_elev = lut_cart[lut_cart[:,0] == sweep-1] # 0-indexed
+                                    
+                # Convert from Swiss-coordinates to array index
+                # wod: 9.02.2022: after careful examination and tests with
+                # random fields it seems that the second index must be incremented by 1
+                # for it to work
+                idx_ch = np.vstack((len(X_QPE_CENTERS)  -
+                                (lut_elev[:,4] - np.min(X_QPE_CENTERS)),
+                                lut_elev[:,3] -  np.min(Y_QPE_CENTERS) + 1)).T
+
+                idx_ch = idx_ch.astype(int)
+                idx_polar = [lut_elev[:,1], lut_elev[:,2]]
+
+                nanadd_at(heights_qpe, idx_ch, lut_coords[sweep][2][idx_polar[0],
+                                                    idx_polar[1]])
+                nanadd_at(weights, idx_ch, np.isfinite(lut_coords[sweep][2][idx_polar[0],
+                                                    idx_polar[1]]))
+                            
+                all_heights_qpe[sweep] = heights_qpe / weights
+
+            lut_names.append(str(lut_name))
+            lut_objects.append(all_heights_qpe)
+
     elif lookup_type == 'station_to_qpegrid':
            
         df_stations = constants.METSTATIONS
@@ -386,7 +445,7 @@ def calc_lookup(lookup_type, radar = None):
         offset_y = int((neighb_y-1)/2)
         
         df_stations = df_stations.append(constants.RADARS)
-            
+        stations = df_stations['Abbrev']
     
         lut = {}
         x_qpe = constants.X_QPE
@@ -401,16 +460,13 @@ def calc_lookup(lookup_type, radar = None):
             
             # For x the columns in the Cartesian lookup tables are lower bounds
             # e.g. x = 563, means that radar pixels are between 563 and 564
-            y_llc_sta = np.int(y_sta / constants.CART_GRID_SIZE)
+            y_llc_sta = int(y_sta / constants.CART_GRID_SIZE)
             # For y the columns in the Cartesian lookup tables are upper bounds
             # e.g. x = 182, means that radar pixels are between 181 and 182            
-            x_llc_sta = np.int(np.ceil(x_sta / constants.CART_GRID_SIZE))
-            
-          
+            x_llc_sta = int(np.ceil(x_sta / constants.CART_GRID_SIZE))
+        
             for i in range(-offset_y, offset_y + 1):
-                print(i)
                 for j in range(-offset_x, offset_x + 1):
-                    print(j)
                     x_llc = x_llc_sta + j
                     y_llc = y_llc_sta + i 
                     # Find index of station in cart grid
@@ -497,11 +553,13 @@ def calc_lookup(lookup_type, radar = None):
 
             lut_names.append(str(lut_name))
             lut_objects.append(lut)
-    
+    else:
+        raise ValueError('Invalid lookup type!')
+ 
     # Dump luts to disk and upload to cloud
     for i in range(len(lut_objects)):
         pickle.dump(lut_objects[i],
-                            open(lut_names[i]),'wb')
+                            open(lut_names[i],'wb'))
         try:
             ObjStorage.upload_file(lut_names[i])
         except AttributeError as e:
@@ -556,6 +614,5 @@ def _WGS_to_COSMO(coords_WGS, SP_coords = (-43,10)):
          coords_COSMO = np.vstack((lat_new, lon_new)).T 
      else: 
          coords_COSMO=np.asarray([lat_new, lon_new]) 
- 
- 
+  
      return coords_COSMO.astype('float32') 
